==> nodehandler-utils-3.0.0-5.tgz: package/README.md <==
# nodehandler-utils

nodehandler utils

# API Reference

**Example** *(Quick start)*  
```javascript
 const { NodeHandlerUtils } = require('nodehandler-utils');
 const { FlowManager } = require('axway-flow');
 const uri = FlowManager.formatNodeHandlerUri('service-connector', 'thing');
 const swagger = require('./thing.json');
 const spec =  NodeHandlerUtils.registerSchemas(swagger, 'thing');
 const spec =  NodeHandlerUtils.swaggerToNodeHandlerSpec(swagger, 'thing', uri, 'thing-icon');
```
<a name="module_nodehandler-utils..NodeHandlerUtils"></a>

### nodehandler-utils~NodeHandlerUtils
Node handler utils

**Kind**: inner class of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
**Access**: public  

* [~NodeHandlerUtils](#module_nodehandler-utils..NodeHandlerUtils)
    * [.getSwaggerMethodAsProperties(swagger, name, verb, path)](#module_nodehandler-utils..NodeHandlerUtils.getSwaggerMethodAsProperties) ⇒ <code>object</code>
    * [.swaggerToNodeHandlerSpec(swagger, name, uri, [icon])](#module_nodehandler-utils..NodeHandlerUtils.swaggerToNodeHandlerSpec) ⇒ <code>object</code>
    * [.registerSchemas(swagger, name)](#module_nodehandler-utils..NodeHandlerUtils.registerSchemas)

<a name="module_nodehandler-utils..NodeHandlerUtils.getSwaggerMethodAsProperties"></a>

#### NodeHandlerUtils.getSwaggerMethodAsProperties(swagger, name, verb, path) ⇒ <code>object</code>
Converts the swagger parameters to json-schema properties.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>object</code> - schema property  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | swagger doc |
| name | <code>string</code> | The name of the node handler |
| verb | <code>object</code> | the method verb |
| path | <code>object</code> | the method path under swagger.paths |

<a name="module_nodehandler-utils..NodeHandlerUtils.swaggerToNodeHandlerSpec"></a>

#### NodeHandlerUtils.swaggerToNodeHandlerSpec(swagger, name, uri, [icon]) ⇒ <code>object</code>
Converts a swagger definition to a node handler spec.  The `uri` uniquely identifies
the node handler, e.g. nodehandler://service-connector/foo (see `FlowManager.formatNodeHandlerUri`).

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>object</code> - node handler spec  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | The swagger document to convert |
| name | <code>string</code> | The name of the node handler |
| uri | <code>string</code> | The unique uri of the node handler |
| [icon] | <code>string</code> | The node handler's icon (defaults to `glyphicon-link`). |

<a name="module_nodehandler-utils..NodeHandlerUtils.registerSchemas"></a>

#### NodeHandlerUtils.registerSchemas(swagger, name)
Registers schema using the`#/definitions` of a swagger document.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | The swagger document to use to register schemas |
| name | <code>string</code> | The name of the node handler |

<a name="module_nodehandler-utils..generateFunctionName"></a>

### nodehandler-utils~generateFunctionName(swpath, method) ⇒ <code>string</code>
Method to create custom operationID-like operation id. Taken from connectors team
NOTE: duplicated from code from arrow-admin-api/src/util.js,

**Kind**: inner method of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
**Returns**: <code>string</code> - The custom operationID  

| Param | Type | Description |
| --- | --- | --- |
| swpath | <code>string</code> | The swagger path (eg. /thing) |
| method | <code>string</code> | The swagger method/verb (eg. "GET") |


## Building

```bash
npm run build
```

## Author

Axway <support@axway.com> https://axway.com

## License

This code is proprietary, closed source software licensed to you by Axway. All Rights Reserved. You may not modify Axway’s code without express written permission of Axway. You are licensed to use and distribute your services developed with the use of this software and dependencies, including distributing reasonable and appropriate portions of the Axway code and dependencies.  Except as set forth above, this code MUST not be copied or otherwise redistributed without express written permission of Axway. This module is licensed as part of the Axway Platform and governed under the terms of the Axway license agreement (General Conditions) located here: [https://support.axway.com/en/auth/general-conditions](https://support.axway.com/en/auth/general-conditions).  Your right to use this software is strictly limited to the term (if any) of the license or subscription originally granted to you.

==> nodehandler-utils-3.0.0-6.tgz: package/README.md <==
# nodehandler-utils

nodehandler utils

# API Reference

**Example** *(Quick start)*  
```javascript
 const { NodeHandlerUtils } = require('nodehandler-utils');
 const { FlowManager } = require('axway-flow');
 const uri = FlowManager.formatNodeHandlerUri('service-connector', 'thing');
 const swagger = require('./thing.json');
 const schemas =  NodeHandlerUtils.exportSchemas(swagger, 'thing');
 const spec =  NodeHandlerUtils.swaggerToNodeHandlerSpec(swagger, 'thing', uri, 'thing-icon');
 const icon = NodeHandlerUtils.loadIcon('icon.png');
```
<a name="module_nodehandler-utils..NodeHandlerUtils"></a>

### nodehandler-utils~NodeHandlerUtils
Node handler utils

**Kind**: inner class of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
**Access**: public  

* [~NodeHandlerUtils](#module_nodehandler-utils..NodeHandlerUtils)
    * [.getSwaggerMethodAsProperties(swagger, name, verb, path)](#module_nodehandler-utils..NodeHandlerUtils.getSwaggerMethodAsProperties) ⇒ <code>object</code>
    * [.swaggerToNodeHandlerSpec(swagger, name, uri, [icon])](#module_nodehandler-utils..NodeHandlerUtils.swaggerToNodeHandlerSpec) ⇒ <code>object</code>
    * [.exportSchemas(swagger, name)](#module_nodehandler-utils..NodeHandlerUtils.exportSchemas) ⇒ <code>array</code>
    * [.loadIcon(file)](#module_nodehandler-utils..NodeHandlerUtils.loadIcon) ⇒ <code>Promise.&lt;string&gt;</code>
    * [.formatNodeHandlerUri(module, type)](#module_nodehandler-utils..NodeHandlerUtils.formatNodeHandlerUri) ⇒ <code>string</code>

<a name="module_nodehandler-utils..NodeHandlerUtils.getSwaggerMethodAsProperties"></a>

#### NodeHandlerUtils.getSwaggerMethodAsProperties(swagger, name, verb, path) ⇒ <code>object</code>
Converts the swagger parameters to json-schema properties.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>object</code> - schema property  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | swagger doc |
| name | <code>string</code> | The name of the node handler |
| verb | <code>object</code> | the method verb |
| path | <code>object</code> | the method path under swagger.paths |

<a name="module_nodehandler-utils..NodeHandlerUtils.swaggerToNodeHandlerSpec"></a>

#### NodeHandlerUtils.swaggerToNodeHandlerSpec(swagger, name, uri, [icon]) ⇒ <code>object</code>
Converts a swagger definition to a node handler spec.  The `uri` uniquely identifies
the node handler, e.g. nodehandler://service-connector/foo (see `FlowManager.formatNodeHandlerUri`).

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>object</code> - node handler spec  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | The swagger document to convert |
| name | <code>string</code> | The name of the node handler |
| uri | <code>string</code> | The unique uri of the node handler |
| [icon] | <code>string</code> | The node handler's icon (defaults to `glyphicon-link`). |

<a name="module_nodehandler-utils..NodeHandlerUtils.exportSchemas"></a>

#### NodeHandlerUtils.exportSchemas(swagger, name) ⇒ <code>array</code>
Exports schema from a swagger document.  Before returning, all of the references are
rewritten to an axway-schema type reference, and identifiers are applied to each
schema.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>array</code> - An array of schemas.  
**Access**: public  

| Param | Type | Description |
| --- | --- | --- |
| swagger | <code>object</code> | The swagger document to use to register schemas |
| name | <code>string</code> | The name of the node handler |

<a name="module_nodehandler-utils..NodeHandlerUtils.loadIcon"></a>

#### NodeHandlerUtils.loadIcon(file) ⇒ <code>Promise.&lt;string&gt;</code>
Loads an icon file and returns it as a data URI.  Supports bmp, jpeg, jpg, png, gif,
tiff, and svg.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>Promise.&lt;string&gt;</code> - The icon data URI.  

| Param | Type | Description |
| --- | --- | --- |
| file | <code>string</code> | The icon file to load. |

<a name="module_nodehandler-utils..NodeHandlerUtils.formatNodeHandlerUri"></a>

#### NodeHandlerUtils.formatNodeHandlerUri(module, type) ⇒ <code>string</code>
Formats a nodehandler URI.

**Kind**: static method of [<code>NodeHandlerUtils</code>](#module_nodehandler-utils..NodeHandlerUtils)  
**Returns**: <code>string</code> - The formatted URI.  

| Param | Type | Description |
| --- | --- | --- |
| module | <code>string</code> | A module name for scope, e.g. "twilio". |
| type | <code>string</code> | A simple URL safe type name, e.g. "echo". |

<a name="module_nodehandler-utils..generateFunctionName"></a>

### nodehandler-utils~generateFunctionName(swpath, method) ⇒ <code>string</code>
Method to create custom operationID-like operation id. Taken from connectors team
NOTE: duplicated from code from arrow-admin-api/src/util.js,

**Kind**: inner method of [<code>nodehandler-utils</code>](#module_nodehandler-utils)  
**Returns**: <code>string</code> - The custom operationID  

| Param | Type | Description |
| --- | --- | --- |
| swpath | <code>string</code> | The swagger path (eg. /thing) |
| method | <code>string</code> | The swagger method/verb (eg. "GET") |


## Building

```bash
npm run build
```

## Author

Axway <support@axway.com> https://axway.com

## License

This code is proprietary, closed source software licensed to you by Axway. All Rights Reserved. You may not modify Axway’s code without express written permission of Axway. You are licensed to use and distribute your services developed with the use of this software and dependencies, including distributing reasonable and appropriate portions of the Axway code and dependencies.  Except as set forth above, this code MUST not be copied or otherwise redistributed without express written permission of Axway. This module is licensed as part of the Axway Platform and governed under the terms of the Axway license agreement (General Conditions) located here: [https://support.axway.com/en/auth/general-conditions](https://support.axway.com/en/auth/general-conditions).  Your right to use this software is strictly limited to the term (if any) of the license or subscription originally granted to you.
